# Nawah CLI
Nawah CLI is the tool to create new Nawah apps. You can install it, and use it like:
```python
python[3[.8]] -m pip install nawah_cli
nawah create [/path/to/project] hello_world [--default-config]
```
where `hello_world` is the new project name and folder name to be created for the project.

# Docs Index
> Learn more on Nawah CLI and Nawah framework at [https://github.com/nawah-io/nawah_docs](https://github.com/nawah-io/nawah_docs).